@@ -13,6 +13,8 @@ fmt = "%(asctime)s.%(msecs)03d\t%(name)-29s\t%(levelname)-8s\t%(funcName)s\t\t %
 # 2020-06-25 15:04:59
 datefmt = "%Y-%m-%d %H:%M:%S"
 
+log_formatter = logging.Formatter(fmt, datefmt)
+
 # %temp%/glasswall/logs/2020-06-25 150459.txt
 log_file_path = os.path.join(glasswall._TEMPDIR, "logs", f'{datetime.now().strftime("%Y-%m-%d %H%M%S")}.txt')
 
@@ -22,12 +24,18 @@ os.makedirs(os.path.dirname(log_file_path), exist_ok=True)
 # Logging to file
 log = logging.getLogger(__name__)
 log_handler = logging.FileHandler(log_file_path, mode="w", delay=True)
-log_handler.setFormatter(logging.Formatter(fmt, datefmt))
+log_handler.setFormatter(log_formatter)
 log.addHandler(log_handler)
-log.setLevel(logging.INFO)
+if os.environ.get("glasswall_log_level"):
+    log.setLevel(os.environ.get("glasswall_log_level"))
+else:
+    log.setLevel(logging.DEBUG)
 
 # Logging to console
 console = logging.StreamHandler()
-console.setFormatter(logging.Formatter(fmt, datefmt))
-console.setLevel(logging.INFO)
+console.setFormatter(log_formatter)
+if os.environ.get("glasswall_console_level"):
+    console.setLevel(os.environ.get("glasswall_console_level"))
+else:
+    console.setLevel(logging.INFO)
 log.addHandler(console)
